@@ -1,5 +1,5 @@
 /***************************************
- $Header: /home/amb/routino/src/RCS/planetsplitter.c,v 1.34 2009/04/08 16:54:34 amb Exp $
+ $Header: /home/amb/routino/src/RCS/planetsplitter.c,v 1.37 2009/06/13 13:02:12 amb Exp $
 
  OSM planet file splitter.
 
@@ -42,7 +42,7 @@ int main(int argc,char** argv)
  WaysX *OSMWays;
  int iteration=0,quit=0;
  int max_iterations=10;
- char *dirname=NULL,*prefix=NULL,*filename;
+ char *dirname=NULL,*prefix=NULL;
  Profile profile;
  int i;
 
@@ -53,7 +53,7 @@ int main(int argc,char** argv)
  profile.allow=Allow_ALL;
 
  for(i=1;i<Way_Unknown;i++)
-    profile.highways[i]=1;
+    profile.highway[i]=1;
 
  for(i=1;i<Way_Unknown;i++)
     profile.speed[i]=0; /* Not used by planetsplitter */
@@ -80,7 +80,7 @@ int main(int argc,char** argv)
     else if(!strncmp(argv[argc],"--not-highway=",14))
       {
        Highway highway=HighwayType(&argv[argc][14]);
-       profile.highways[highway]=0;
+       profile.highway[highway]=0;
       }
     else
       {
@@ -126,9 +126,13 @@ int main(int argc,char** argv)
 
  SortSegmentList(OSMSegments);
 
+ /* Sort the nodes */
+
+ SortNodeList(OSMNodes);
+
  /* Remove bad segments */
 
- RemoveBadSegments(OSMSegments);
+ RemoveBadSegments(OSMNodes,OSMSegments);
 
  SortSegmentList(OSMSegments);
 
@@ -230,20 +234,15 @@ int main(int argc,char** argv)
 
  /* Write out the nodes */
 
- filename=(char*)malloc((dirname?strlen(dirname):0)+(prefix?strlen(prefix):0)+16);
-
- sprintf(filename,"%s%s%s%snodes.mem",dirname?dirname:"",dirname?"/":"",prefix?prefix:"",prefix?"-":"");
- SaveNodeList(OSMNodes,filename);
+ SaveNodeList(OSMNodes,FileName(dirname,prefix,"nodes.mem"));
 
  /* Write out the segments */
 
- sprintf(filename,"%s%s%s%ssegments.mem",dirname?dirname:"",dirname?"/":"",prefix?prefix:"",prefix?"-":"");
- SaveSegmentList(OSMSegments,filename);
+ SaveSegmentList(OSMSegments,FileName(dirname,prefix,"segments.mem"));
 
  /* Write out the ways */
 
- sprintf(filename,"%s%s%s%sways.mem",dirname?dirname:"",dirname?"/":"",prefix?prefix:"",prefix?"-":"");
- SaveWayList(OSMWays,filename);
+ SaveWayList(OSMWays,FileName(dirname,prefix,"ways.mem"));
 
  return(0);
 }
