@@ -1,5 +1,5 @@
 /***************************************
- $Header: /home/amb/routino/src/RCS/profiles.c,v 1.11 2009/04/08 16:54:34 amb Exp $
+ $Header: /home/amb/routino/src/RCS/profiles.c,v 1.16 2009/05/23 16:55:14 amb Exp $
 
  The pre-defined profiles and the functions for handling them.
 
@@ -36,20 +36,20 @@ static Profile builtin_profiles[]=
   [Transport_Foot] = {
                       .transport=Transport_Foot,
                       .allow    =Allow_Foot,
-                      .highways = {
-                                   [Way_Motorway    ] = 0,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 1,
-                                   [Way_Path        ] = 1,
-                                   [Way_Bridleway   ] = 1,
-                                   [Way_Cycleway    ] = 1,
-                                   [Way_Footway     ] = 1,
+                      .highway  = {
+                                   [Way_Motorway    ] =   0,
+                                   [Way_Trunk       ] =  40,
+                                   [Way_Primary     ] =  50,
+                                   [Way_Secondary   ] =  60,
+                                   [Way_Tertiary    ] =  70,
+                                   [Way_Unclassified] =  80,
+                                   [Way_Residential ] =  90,
+                                   [Way_Service     ] =  90,
+                                   [Way_Track       ] =  95,
+                                   [Way_Path        ] = 100,
+                                   [Way_Bridleway   ] = 100,
+                                   [Way_Cycleway    ] =  95,
+                                   [Way_Footway     ] = 100,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = 0,
@@ -78,20 +78,20 @@ static Profile builtin_profiles[]=
   [Transport_Bicycle] = {
                       .transport=Transport_Bicycle,
                       .allow    =Allow_Bicycle,
-                      .highways = {
-                                   [Way_Motorway    ] = 0,
-                                   [Way_Trunk       ] = 0,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 1,
-                                   [Way_Path        ] = 1,
-                                   [Way_Bridleway   ] = 1,
-                                   [Way_Cycleway    ] = 1,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] =   0,
+                                   [Way_Trunk       ] =  30,
+                                   [Way_Primary     ] =  70,
+                                   [Way_Secondary   ] =  80,
+                                   [Way_Tertiary    ] =  90,
+                                   [Way_Unclassified] =  90,
+                                   [Way_Residential ] =  90,
+                                   [Way_Service     ] =  90,
+                                   [Way_Track       ] =  90,
+                                   [Way_Path        ] =  90,
+                                   [Way_Bridleway   ] =  90,
+                                   [Way_Cycleway    ] = 100,
+                                   [Way_Footway     ] =  90,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = 0,
@@ -106,7 +106,7 @@ static Profile builtin_profiles[]=
                                    [Way_Path        ] = kph_to_speed(20),
                                    [Way_Bridleway   ] = kph_to_speed(20),
                                    [Way_Cycleway    ] = kph_to_speed(20),
-                                   [Way_Footway     ] = 0,
+                                   [Way_Footway     ] = kph_to_speed(20),
                                   },
                       .oneway   = 1,
                       .weight   = 0,
@@ -120,35 +120,35 @@ static Profile builtin_profiles[]=
   [Transport_Horse] = {
                       .transport=Transport_Horse,
                       .allow    =Allow_Horse,
-                      .highways = {
-                                   [Way_Motorway    ] = 0,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 1,
-                                   [Way_Path        ] = 1,
-                                   [Way_Bridleway   ] = 1,
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] =   0,
+                                   [Way_Trunk       ] =  25,
+                                   [Way_Primary     ] =  50,
+                                   [Way_Secondary   ] =  50,
+                                   [Way_Tertiary    ] =  75,
+                                   [Way_Unclassified] =  75,
+                                   [Way_Residential ] =  75,
+                                   [Way_Service     ] =  75,
+                                   [Way_Track       ] = 100,
+                                   [Way_Path        ] = 100,
+                                   [Way_Bridleway   ] = 100,
+                                   [Way_Cycleway    ] =  90,
+                                   [Way_Footway     ] =  90,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = 0,
                                    [Way_Trunk       ] = 0,
-                                   [Way_Primary     ] = kph_to_speed(10),
-                                   [Way_Secondary   ] = kph_to_speed(10),
-                                   [Way_Tertiary    ] = kph_to_speed(10),
-                                   [Way_Unclassified] = kph_to_speed(10),
-                                   [Way_Residential ] = kph_to_speed(10),
-                                   [Way_Service     ] = kph_to_speed(10),
-                                   [Way_Track       ] = kph_to_speed(10),
-                                   [Way_Path        ] = kph_to_speed(10),
-                                   [Way_Bridleway   ] = kph_to_speed(10),
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                                   [Way_Primary     ] = kph_to_speed(8),
+                                   [Way_Secondary   ] = kph_to_speed(8),
+                                   [Way_Tertiary    ] = kph_to_speed(8),
+                                   [Way_Unclassified] = kph_to_speed(8),
+                                   [Way_Residential ] = kph_to_speed(8),
+                                   [Way_Service     ] = kph_to_speed(8),
+                                   [Way_Track       ] = kph_to_speed(8),
+                                   [Way_Path        ] = kph_to_speed(8),
+                                   [Way_Bridleway   ] = kph_to_speed(8),
+                                   [Way_Cycleway    ] = kph_to_speed(8),
+                                   [Way_Footway     ] = kph_to_speed(8),
                                   },
                       .oneway   = 1,
                       .weight   = 0,
@@ -162,20 +162,20 @@ static Profile builtin_profiles[]=
   [Transport_Motorbike] = {
                       .transport=Transport_Motorbike,
                       .allow    =Allow_Motorbike,
-                      .highways = {
-                                   [Way_Motorway    ] = 1,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 0,
-                                   [Way_Path        ] = 0,
-                                   [Way_Bridleway   ] = 0,
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] = 100,
+                                   [Way_Trunk       ] = 100,
+                                   [Way_Primary     ] =  90,
+                                   [Way_Secondary   ] =  80,
+                                   [Way_Tertiary    ] =  70,
+                                   [Way_Unclassified] =  60,
+                                   [Way_Residential ] =  50,
+                                   [Way_Service     ] =  80,
+                                   [Way_Track       ] =   0,
+                                   [Way_Path        ] =   0,
+                                   [Way_Bridleway   ] =   0,
+                                   [Way_Cycleway    ] =   0,
+                                   [Way_Footway     ] =   0,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = kph_to_speed(70*1.6),
@@ -186,7 +186,7 @@ static Profile builtin_profiles[]=
                                    [Way_Unclassified] = kph_to_speed(40*1.6),
                                    [Way_Residential ] = kph_to_speed(30*1.6),
                                    [Way_Service     ] = kph_to_speed(20*1.6),
-                                   [Way_Track       ] = 0,
+                                   [Way_Track       ] = kph_to_speed(10*1.6),
                                    [Way_Path        ] = 0,
                                    [Way_Bridleway   ] = 0,
                                    [Way_Cycleway    ] = 0,
@@ -204,20 +204,20 @@ static Profile builtin_profiles[]=
   [Transport_Motorcar] = {
                       .transport=Transport_Motorcar,
                       .allow    =Allow_Motorcar,
-                      .highways = {
-                                   [Way_Motorway    ] = 1,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 0,
-                                   [Way_Path        ] = 0,
-                                   [Way_Bridleway   ] = 0,
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] = 100,
+                                   [Way_Trunk       ] = 100,
+                                   [Way_Primary     ] =  90,
+                                   [Way_Secondary   ] =  80,
+                                   [Way_Tertiary    ] =  70,
+                                   [Way_Unclassified] =  60,
+                                   [Way_Residential ] =  50,
+                                   [Way_Service     ] =  80,
+                                   [Way_Track       ] =   0,
+                                   [Way_Path        ] =   0,
+                                   [Way_Bridleway   ] =   0,
+                                   [Way_Cycleway    ] =   0,
+                                   [Way_Footway     ] =   0,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = kph_to_speed(70*1.6),
@@ -228,7 +228,7 @@ static Profile builtin_profiles[]=
                                    [Way_Unclassified] = kph_to_speed(40*1.6),
                                    [Way_Residential ] = kph_to_speed(30*1.6),
                                    [Way_Service     ] = kph_to_speed(20*1.6),
-                                   [Way_Track       ] = 0,
+                                   [Way_Track       ] = kph_to_speed(10*1.6),
                                    [Way_Path        ] = 0,
                                    [Way_Bridleway   ] = 0,
                                    [Way_Cycleway    ] = 0,
@@ -246,20 +246,20 @@ static Profile builtin_profiles[]=
   [Transport_Goods] = {
                       .transport=Transport_Goods,
                       .allow    =Allow_Goods,
-                      .highways = {
-                                   [Way_Motorway    ] = 1,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 0,
-                                   [Way_Path        ] = 0,
-                                   [Way_Bridleway   ] = 0,
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] = 100,
+                                   [Way_Trunk       ] = 100,
+                                   [Way_Primary     ] =  90,
+                                   [Way_Secondary   ] =  80,
+                                   [Way_Tertiary    ] =  70,
+                                   [Way_Unclassified] =  60,
+                                   [Way_Residential ] =  50,
+                                   [Way_Service     ] =  80,
+                                   [Way_Track       ] =   0,
+                                   [Way_Path        ] =   0,
+                                   [Way_Bridleway   ] =   0,
+                                   [Way_Cycleway    ] =   0,
+                                   [Way_Footway     ] =   0,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = kph_to_speed(60*1.6),
@@ -270,7 +270,7 @@ static Profile builtin_profiles[]=
                                    [Way_Unclassified] = kph_to_speed(40*1.6),
                                    [Way_Residential ] = kph_to_speed(30*1.6),
                                    [Way_Service     ] = kph_to_speed(20*1.6),
-                                   [Way_Track       ] = 0,
+                                   [Way_Track       ] = kph_to_speed(10*1.6),
                                    [Way_Path        ] = 0,
                                    [Way_Bridleway   ] = 0,
                                    [Way_Cycleway    ] = 0,
@@ -288,20 +288,20 @@ static Profile builtin_profiles[]=
   [Transport_HGV] = {
                       .transport=Transport_HGV,
                       .allow    =Allow_HGV,
-                      .highways = {
-                                   [Way_Motorway    ] = 1,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 0,
-                                   [Way_Path        ] = 0,
-                                   [Way_Bridleway   ] = 0,
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] = 100,
+                                   [Way_Trunk       ] = 100,
+                                   [Way_Primary     ] =  90,
+                                   [Way_Secondary   ] =  80,
+                                   [Way_Tertiary    ] =  70,
+                                   [Way_Unclassified] =  60,
+                                   [Way_Residential ] =  50,
+                                   [Way_Service     ] =  80,
+                                   [Way_Track       ] =   0,
+                                   [Way_Path        ] =   0,
+                                   [Way_Bridleway   ] =   0,
+                                   [Way_Cycleway    ] =   0,
+                                   [Way_Footway     ] =   0,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = kph_to_speed(56*1.6),
@@ -312,7 +312,7 @@ static Profile builtin_profiles[]=
                                    [Way_Unclassified] = kph_to_speed(40*1.6),
                                    [Way_Residential ] = kph_to_speed(30*1.6),
                                    [Way_Service     ] = kph_to_speed(20*1.6),
-                                   [Way_Track       ] = 0,
+                                   [Way_Track       ] = kph_to_speed(10*1.6),
                                    [Way_Path        ] = 0,
                                    [Way_Bridleway   ] = 0,
                                    [Way_Cycleway    ] = 0,
@@ -330,20 +330,20 @@ static Profile builtin_profiles[]=
   [Transport_PSV] = {
                       .transport=Transport_PSV,
                       .allow    =Allow_PSV,
-                      .highways = {
-                                   [Way_Motorway    ] = 1,
-                                   [Way_Trunk       ] = 1,
-                                   [Way_Primary     ] = 1,
-                                   [Way_Secondary   ] = 1,
-                                   [Way_Tertiary    ] = 1,
-                                   [Way_Unclassified] = 1,
-                                   [Way_Residential ] = 1,
-                                   [Way_Service     ] = 1,
-                                   [Way_Track       ] = 0,
-                                   [Way_Path        ] = 0,
-                                   [Way_Bridleway   ] = 0,
-                                   [Way_Cycleway    ] = 0,
-                                   [Way_Footway     ] = 0,
+                      .highway  = {
+                                   [Way_Motorway    ] = 100,
+                                   [Way_Trunk       ] = 100,
+                                   [Way_Primary     ] =  90,
+                                   [Way_Secondary   ] =  80,
+                                   [Way_Tertiary    ] =  70,
+                                   [Way_Unclassified] =  60,
+                                   [Way_Residential ] =  50,
+                                   [Way_Service     ] =  80,
+                                   [Way_Track       ] =   0,
+                                   [Way_Path        ] =   0,
+                                   [Way_Bridleway   ] =   0,
+                                   [Way_Cycleway    ] =   0,
+                                   [Way_Footway     ] =   0,
                                   },
                       .speed    = {
                                    [Way_Motorway    ] = kph_to_speed(56*1.6),
@@ -354,7 +354,7 @@ static Profile builtin_profiles[]=
                                    [Way_Unclassified] = kph_to_speed(40*1.6),
                                    [Way_Residential ] = kph_to_speed(30*1.6),
                                    [Way_Service     ] = kph_to_speed(20*1.6),
-                                   [Way_Track       ] = 0,
+                                   [Way_Track       ] = kph_to_speed(10*1.6),
                                    [Way_Path        ] = 0,
                                    [Way_Bridleway   ] = 0,
                                    [Way_Cycleway    ] = 0,
@@ -383,6 +383,45 @@ Profile *GetProfile(Transport transport)
 }
 
 
+/*++++++++++++++++++++++++++++++++++++++
+  Update a profile with highway preference scaling factor.
+
+  Profile *profile The profile to be updated.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void UpdateProfile(Profile *profile)
+{
+ score_t hmax=0;
+ int i;
+
+ /* Normalise the highway preferences into the range 0 -> 1 */
+
+ for(i=1;i<Way_Unknown;i++)
+    if(profile->highway[i]>hmax)
+       hmax=profile->highway[i];
+
+ for(i=1;i<Way_Unknown;i++)
+    if(profile->highway[i]>0)
+       profile->highway[i]/=hmax;
+    else
+       profile->highway[i]=0;
+
+ /* Find the fastest and most preferred highway type */
+
+ profile->max_speed=0;
+
+ for(i=0;i<Way_Unknown;i++)
+    if(profile->speed[i]>profile->max_speed)
+       profile->max_speed=profile->speed[i];
+
+ profile->max_pref=0;
+
+ for(i=0;i<Way_Unknown;i++)
+    if(profile->highway[i]>profile->max_pref)
+       profile->max_pref=profile->highway[i];
+}
+
+
 /*++++++++++++++++++++++++++++++++++++++
   Print out a profile.
 
@@ -402,12 +441,12 @@ void PrintProfile(const Profile *profile)
  printf("\n");
 
  for(i=1;i<Way_Unknown;i++)
-    printf("Highway %-12s: %s\n",HighwayName(i),profile->highways[i]?"yes":"no");
+    printf("Highway %-12s: %3d%%\n",HighwayName(i),(int)profile->highway[i]);
 
  printf("\n");
 
  for(i=1;i<Way_Unknown;i++)
-    if(profile->highways[i])
+    if(profile->highway[i])
        printf("Speed on %-12s: %3d km/h / %2.0f mph\n",HighwayName(i),profile->speed[i],(double)profile->speed[i]/1.6);
 
  printf("\n");
@@ -429,70 +468,70 @@ void PrintProfilesJS(void)
  int i,j;
 
  printf("// Transport types\n");
- printf("router_transports={");
+ printf("var router_transports={");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s%s: %d",j==1?"":",",TransportName(j),j-1);
+    printf("%s%s: %d",j==1?"":", ",TransportName(j),j-1);
  printf("};\n");
  printf("\n");
 
  printf("// Highway types\n");
- printf("router_highways={");
+ printf("var router_highways={");
  for(i=1;i<Way_Unknown;i++)
-    printf("%s%s: %d",i==1?"":",",HighwayName(i),i-1);
+    printf("%s%s: %d",i==1?"":", ",HighwayName(i),i-1);
  printf("};\n");
  printf("\n");
 
  printf("// Restriction types\n");
- printf("router_restrictions={oneway: 1, weight: 2, height: 3, width: 4, length: 5};\n");
+ printf("var router_restrictions={oneway: 1, weight: 2, height: 3, width: 4, length: 5};\n");
  printf("\n");
 
  printf("// Allowed highways\n");
- printf("router_profile_highway={\n");
+ printf("var router_profile_highway={\n");
  for(i=1;i<Way_Unknown;i++)
    {
     printf("  %12s: {",HighwayName(i));
     for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-       printf("%s%s: %d",j==1?"":",",TransportName(j),builtin_profiles[j].highways[i]);
-    printf("}%s\n",i==(Way_Unknown-1)?"":",");
+       printf("%s%s: %3d",j==1?"":", ",TransportName(j),(int)builtin_profiles[j].highway[i]);
+    printf("}%s\n",i==(Way_Unknown-1)?"":", ");
    }
  printf("   };\n");
  printf("\n");
 
  printf("// Speed limits\n");
- printf("router_profile_speed={\n");
+ printf("var router_profile_speed={\n");
  for(i=1;i<Way_Unknown;i++)
    {
     printf("  %12s: {",HighwayName(i));
     for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-       printf("%s%s: %3d",j==1?"":",",TransportName(j),builtin_profiles[j].speed[i]);
-    printf("}%s\n",i==(Way_Unknown-1)?"":",");
+       printf("%s%s: %3d",j==1?"":", ",TransportName(j),builtin_profiles[j].speed[i]);
+    printf("}%s\n",i==(Way_Unknown-1)?"":", ");
    }
  printf("   };\n");
  printf("\n");
 
  printf("// Restrictions\n");
- printf("router_profile_restrictions={\n");
- printf("oneway: {");
+ printf("var router_profile_restrictions={\n");
+ printf("  %12s: {","oneway");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s%s: %d",j==1?"":",",TransportName(j),builtin_profiles[j].oneway);
+    printf("%s%s: %4d",j==1?"":", ",TransportName(j),builtin_profiles[j].oneway);
  printf("},\n");
  printf("  %12s: {","weight");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s%s: %.1f",j==1?"":",",TransportName(j),weight_to_tonnes(builtin_profiles[j].weight));
+    printf("%s%s: %4.1f",j==1?"":", ",TransportName(j),weight_to_tonnes(builtin_profiles[j].weight));
  printf("},\n");
  printf("  %12s: {","height");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s%s: %.1f",j==1?"":",",TransportName(j),height_to_metres(builtin_profiles[j].height));
+    printf("%s%s: %4.1f",j==1?"":", ",TransportName(j),height_to_metres(builtin_profiles[j].height));
  printf("},\n");
  printf("  %12s: {","width");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s%s: %.1f",j==1?"":",",TransportName(j),width_to_metres(builtin_profiles[j].width));
+    printf("%s%s: %4.1f",j==1?"":", ",TransportName(j),width_to_metres(builtin_profiles[j].width));
  printf("},\n");
  printf("  %12s: {","length");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s%s: %.1f",j==1?"":",",TransportName(j),length_to_metres(builtin_profiles[j].length));
+    printf("%s%s: %4.1f",j==1?"":", ",TransportName(j),length_to_metres(builtin_profiles[j].length));
  printf("}\n");
- printf("};\n");
+ printf("   };\n");
  printf("\n");
 }
 
@@ -529,8 +568,8 @@ void PrintProfilesPerl(void)
    {
     printf("  %12s => {",HighwayName(i));
     for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-       printf("%s %s => %d",j==1?"":",",TransportName(j),builtin_profiles[j].highways[i]);
-    printf("}%s\n",i==(Way_Unknown-1)?"":",");
+       printf("%s %s => %3d",j==1?"":", ",TransportName(j),(int)builtin_profiles[j].highway[i]);
+    printf("}%s\n",i==(Way_Unknown-1)?"":", ");
    }
  printf("   );\n");
  printf("\n");
@@ -541,34 +580,34 @@ void PrintProfilesPerl(void)
    {
     printf("  %12s => {",HighwayName(i));
     for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-       printf("%s %s => %3d",j==1?"":",",TransportName(j),builtin_profiles[j].speed[i]);
-    printf("}%s\n",i==(Way_Unknown-1)?"":",");
+       printf("%s %s => %3d",j==1?"":", ",TransportName(j),builtin_profiles[j].speed[i]);
+    printf("}%s\n",i==(Way_Unknown-1)?"":", ");
    }
  printf("   );\n");
  printf("\n");
 
  printf("# Restrictions\n");
  printf("%%router_profile_restrictions=(\n");
- printf("oneway => {");
+ printf("  %12s => {","oneway");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s %s => %d",j==1?"":",",TransportName(j),builtin_profiles[j].oneway);
+    printf("%s %s => %4d",j==1?"":", ",TransportName(j),builtin_profiles[j].oneway);
  printf("},\n");
  printf("  %12s => {","weight");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s %s => %.1f",j==1?"":",",TransportName(j),weight_to_tonnes(builtin_profiles[j].weight));
+    printf("%s %s => %4.1f",j==1?"":", ",TransportName(j),weight_to_tonnes(builtin_profiles[j].weight));
  printf("},\n");
  printf("  %12s => {","height");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s %s => %.1f",j==1?"":",",TransportName(j),height_to_metres(builtin_profiles[j].height));
+    printf("%s %s => %4.1f",j==1?"":", ",TransportName(j),height_to_metres(builtin_profiles[j].height));
  printf("},\n");
  printf("  %12s => {","width");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s %s => %.1f",j==1?"":",",TransportName(j),width_to_metres(builtin_profiles[j].width));
+    printf("%s %s => %4.1f",j==1?"":", ",TransportName(j),width_to_metres(builtin_profiles[j].width));
  printf("},\n");
  printf("  %12s => {","length");
  for(j=1;j<sizeof(builtin_profiles)/sizeof(builtin_profiles[0]);j++)
-    printf("%s %s => %.1f",j==1?"":",",TransportName(j),length_to_metres(builtin_profiles[j].length));
+    printf("%s %s => %4.1f",j==1?"":", ",TransportName(j),length_to_metres(builtin_profiles[j].length));
  printf("}\n");
- printf(");\n");
+ printf("   );\n");
  printf("\n");
 }
