@@ -1,5 +1,5 @@
 /***************************************
- $Header: /home/amb/routino/src/RCS/results.c,v 1.10 2009/04/08 16:54:34 amb Exp $
+ $Header: /home/amb/routino/src/RCS/results.c,v 1.14 2009/05/14 18:02:30 amb Exp $
 
  Result data type functions.
 
@@ -88,6 +88,9 @@ Results *NewResultsList(int nbins)
  results->data=(Result**)malloc(1*sizeof(Result*));
  results->data[0]=(Result*)malloc(results->nbins*RESULTS_INCREMENT*sizeof(Result));
 
+ results->start=NO_NODE;
+ results->finish=NO_NODE;
+
  return(results);
 }
 
@@ -160,10 +163,30 @@ Result *InsertResult(Results *results,index_t node)
 
  results->count[bin]++;
 
+ results->point[bin][results->count[bin]-1]->node=node;
+
  return(results->point[bin][results->count[bin]-1]);
 }
 
 
+/*++++++++++++++++++++++++++++++++++++++
+  Zero the values in a result structure.
+
+  Result *result The result to modify.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void ZeroResult(Result *result)
+{
+ result->prev=NO_NODE;
+ result->next=NO_NODE;
+
+ result->score=0;
+ result->sortby=0;
+
+ result->segment=NULL;
+}
+
+
 /*++++++++++++++++++++++++++++++++++++++
   Find a result; search by node.
 
